@@ -107,6 +107,16 @@ class InvalidAudience(JOSEException):
     code = "INVALID_AUDIENCE"
     message = "The audience of the JSON Web Token (JWT) is invalid."
 
+    @classmethod
+    def with_detail(cls, asserted: list, required: list):
+        asserted = [x[:128] for x in asserted]
+        return cls(
+            message=(
+                "Audience(s): {str.join(', ', asserted)} did not intersect with"
+                " {str.join(', ', required)}."
+            )
+        )
+
 
 class MissingClaims(JOSEException):
     code = "MISSING_CLAIMS"
